Skip to contents

A wrapper around the missForest::missForest(). Impute missing values using recursive running of random forests until convergence. This is a non-parametric method and works for both MAR and MNAR missing data.

Usage

impute_miss_forest(x, by = NULL, seed = 123, ...)

Arguments

x

A glyexp::GlycomicSE(), glyexp::GlycoproteomicSE(), or SummarizedExperiment::SummarizedExperiment() object.

by

Either a column name in sample_info (string) or a factor/vector specifying group assignments for each sample. Used for grouping when imputing missing values.

seed

Integer seed for random number generation. Default is 123.

...

Additional arguments to pass to missForest::missForest().

Value

A container of the same class as x, with missing values imputed.