PPCA Imputation
impute_ppca.RdA wrapper around the pcaMethods::pca().
Impute missing values using probabilistic principal component analysis (PPCA).
PPCA allows to perform PCA on incomplete data and may be used for missing value estimation.
Arguments
- x
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- by
Either a column name in
sample_info(string) or a factor/vector specifying group assignments for each sample. Used for grouping when imputing missing values.- ...
Additional arguments to pass to
pcaMethods::pca().