Skip to contents

This function is a wrapper around limma::normalizeCyclicLoess() with method = "pairs". Each pair of columns is normalized mutually to each other. See this paper for more information. Also see limma::normalizeCyclicLoess().

Usage

normalize_loesscyc(x, by = NULL, ...)

Arguments

x

A glyexp::GlycomicSE(), glyexp::GlycoproteomicSE(), or SummarizedExperiment::SummarizedExperiment() object.

by

Either a column name in sample_info (string) or a factor/vector specifying group assignments for each sample. Optional. If provided, the normalization will be performed within each group.

...

Additional arguments to pass to limma::normalizeCyclicLoess().

Value

A container of the same class as x, with a normalized expression matrix.