Skip to contents

This function is a wrapper around limma::normalizeCyclicLoess() with method = "fast". Each column is simply normalized to a reference array, the reference array being the average of all the arrays. See this paper for more information. Also see limma::normalizeCyclicLoess().

Usage

normalize_loessf(x, by = NULL, ...)

Arguments

x

A glyexp::GlycomicSE(), glyexp::GlycoproteomicSE(), or SummarizedExperiment::SummarizedExperiment() object.

by

Either a column name in sample_info (string) or a factor/vector specifying group assignments for each sample. Optional. If provided, the normalization will be performed within each group.

...

Additional arguments to pass to limma::normalizeCyclicLoess().

Value

A container of the same class as x, with a normalized expression matrix.