Skip to contents

Normalize the expression matrix by dividing each column (sample) by the absolute median of that column (NA ignored), so that the absolute median of each column is 1.

Usage

normalize_median_abs(x)

Value

A container of the same class as x, with a normalized expression matrix.