Quantile Normalization
normalize_quantile.RdThis function is a wrapper around limma::normalizeQuantiles().
It normalizes the expression matrix by quantile normalization.
This method is used to remove technical variation between samples.
Proteomics data rarely uses this method, but it is common in microarray data.
See wikipedia
for more information.
Arguments
- x
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- by
Either a column name in
sample_info(string) or a factor/vector specifying group assignments for each sample. Optional. If provided, the normalization will be performed within each group.- ...
Additional arguments to pass to
limma::normalizeQuantiles().