Skip to contents

Normalize the expression matrix by dividing each column (sample) by the sum of that column, so that the sum of each column is 1. This is the most common normalization method for glycomics data. It removes the bias introduced by total glycan abundance. However, it results in compositional data, which may result in unrealistic downstream analysis results.

Usage

normalize_total_area(x)

Value

A container of the same class as x, with a normalized expression matrix.