Variance Stabilizing Normalization
normalize_vsn.RdThis function is a wrapper around limma::normalizeVSN().
Evidence proved that this method performs well in reducing noise and
boosting differential expression detection.
Log-transformation is not needed for downstream statistical analysis,
for this normalization method performs a log-like transformation internally.
Due to the same reason, fold change estimates will be severely distorted.
Please use this method with caution.
See this paper for more information.
Arguments
- x
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- by
Either a column name in
sample_info(string) or a factor/vector specifying group assignments for each sample. Optional. If provided, the normalization will be performed within each group.- ...
Additional arguments to pass to
limma::normalizeVSN().