Plot CV Density
plot_cv_dent.RdCompute coefficient of variation (CV) for each variable and plot its density.
When by is provided, CVs are computed within each group and densities are
shown with different fills.
Arguments
- exp
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- by
Grouping variable for samples. Can be a column name in
sample_infoor a vector/factor with length equal to the number of samples. When provided, CVs are computed within each group and densities are shown with different fills.
Examples
plot_cv_dent(glyexp::real_experiment)
library(SummarizedExperiment)
exp <- glyexp::real_experiment
group <- rep(c("A", "B"), length.out = ncol(exp))
colData(exp)$group <- group
plot_cv_dent(exp, by = "group")