Skip to contents

Draw boxplots of log2-transformed intensities for each sample. Optionally color and group samples by a metadata variable.

Usage

plot_int_boxplot(exp, by = NULL)

Arguments

exp

A glyexp::GlycomicSE(), glyexp::GlycoproteomicSE(), or SummarizedExperiment::SummarizedExperiment() object.

by

Grouping variable for samples. Can be a column name in sample_info or a vector/factor with length equal to the number of samples. When provided, samples are grouped along the x-axis and boxplots are colored by group.

Value

A ggplot object of log-intensity boxplots.

Examples

plot_int_boxplot(glyexp::real_experiment)
#> Warning: Removed 4063 rows containing non-finite outside the scale range
#> (`stat_boxplot()`).

plot_int_boxplot(glyexp::real_experiment, by = "group")
#> Warning: Removed 4063 rows containing non-finite outside the scale range
#> (`stat_boxplot()`).