Skip to contents

Draw a bar plot of missing value proportions for each sample or variable. Items are ordered from low to high missing proportion.

Usage

plot_missing_bar(exp, on = "sample")

Arguments

exp

A glyexp::GlycomicSE(), glyexp::GlycoproteomicSE(), or SummarizedExperiment::SummarizedExperiment() object.

on

Whether to plot missingness by "sample(s)" or "variable(s)". Defaults to "sample".

Value

A ggplot object of missing value proportions by item.

Examples

plot_missing_bar(glyexp::real_experiment)