Skip to contents

Draw boxplots of relative log expression (log2 intensity minus row median) for each sample. Optionally color and group samples by a metadata variable.

Usage

plot_rle(exp, by = NULL)

Arguments

exp

A glyexp::GlycomicSE(), glyexp::GlycoproteomicSE(), or SummarizedExperiment::SummarizedExperiment() object.

by

Grouping variable for samples. Can be a column name in sample_info or a vector/factor with length equal to the number of samples. When provided, samples are grouped along the x-axis and boxplots are colored by group.

Value

A ggplot object of RLE boxplots.

Examples

plot_rle(glyexp::real_experiment)
#> Warning: Removed 4063 rows containing non-finite outside the scale range
#> (`stat_boxplot()`).

plot_rle(glyexp::real_experiment, by = "group")
#> Warning: Removed 4063 rows containing non-finite outside the scale range
#> (`stat_boxplot()`).