Remove Constant Variables
remove_constant.RdConstant variables are variables with the same value in all samples.
This function is equivalent to remove_low_var(x, var_cutoff = 0, by = by, strict = strict).
Arguments
- x
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- by
Either a column name in
sample_info(string) or a vector specifying group assignments for each sample.- strict
If
FALSE, remove a variable only if it is constant in all groups. IfTRUE, remove a variable if it is constant in any group. Defaults to FALSE.