Skip to contents

Filters variables whose variance falls below a threshold. Default behavior is to remove variables with zero variance.

Usage

remove_low_var(x, var_cutoff = 0, by = NULL, strict = FALSE)

Arguments

x

A glyexp::GlycomicSE(), glyexp::GlycoproteomicSE(), or SummarizedExperiment::SummarizedExperiment() object.

var_cutoff

The cutoff for variance. Defaults to 0.

by

A factor specifying the groupings. Defaults to NULL.

strict

If FALSE, remove a variable only if it passes the variance threshold in all groups. If TRUE, remove a variable if it passes the variance threshold in any group.

Value

A container of the same class as x, with filtered variables.