Automatic Normalization
auto_normalize.RdThis function automatically applies a deterministic default normalization method based on experiment type. Quality Control (QC) samples are not used to benchmark, select, or report normalization behavior.
Arguments
- exp
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- group_col
The column name in sample_info for groups. Default is "group". Can be NULL when no group information is available.
Details
The automatic strategy uses these defaults:
glycomics:normalize_total_area().glycoproteomics:normalize_median().missing or other experiment types:
normalize_median().