Skip to contents

This function automatically applies a deterministic default normalization method based on experiment type. Quality Control (QC) samples are not used to benchmark, select, or report normalization behavior.

Usage

auto_normalize(exp, group_col = "group", qc_name = "QC", to_try = NULL)

Arguments

exp

An glyexp::experiment().

group_col

The column name in sample_info for groups. Default is "group". Can be NULL when no group information is available.

qc_name

[Deprecated] This function no longer uses this argument. This parameter is ignored and will be removed in a future release.

to_try

[Deprecated] This parameter is no longer used and will be removed in a future release. The automatic strategy is now deterministic and does not require user-specified methods to try.

Value

The normalized experiment.

Details

The automatic strategy uses these defaults:

Examples

library(glyexp)
exp_normed <- auto_normalize(real_experiment)
#>  Normalization method: `normalize_median()`
#>  Reason: default for "glycoproteomics".