Automatic Normalization
auto_normalize.RdThis function automatically applies a deterministic default normalization method based on experiment type. Quality Control (QC) samples are not used to benchmark, select, or report normalization behavior.
Arguments
- exp
- group_col
The column name in sample_info for groups. Default is "group". Can be NULL when no group information is available.
- qc_name
This function no longer uses this argument. This parameter is ignored and will be removed in a future release.
- to_try
This parameter is no longer used and will be removed in a future release. The automatic strategy is now deterministic and does not require user-specified methods to try.
Details
The automatic strategy uses these defaults:
glycomics:normalize_total_area().glycoproteomics:normalize_median().missing or other experiment types:
normalize_median().