BPCA Imputation
impute_bpca.RdA wrapper around the pcaMethods::pca().
Impute missing values using Bayesian principal component analysis (BPCA).
BPCA combines an EM approach for PCA with a Bayesian model.
In standard PCA data far from the training set but close to the principal
subspace may have the same reconstruction error.
BPCA defines a likelihood function such that the likelihood for data far from
the training set is much lower, even if they are close to the principal subspace.
Arguments
- x
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- by
Either a column name in
sample_info(string) or a factor/vector specifying group assignments for each sample. Used for grouping when imputing missing values.- ...
Additional arguments to pass to
pcaMethods::pca().