SVD Imputation
impute_svd.RdA wrapper around the pcaMethods::pca().
Impute missing values using singular value decomposition (SVD) imputation.
SVD is a matrix factorization technique that factors a matrix into three matrices:
U, Σ, and V. SVD is used to find the best lower rank approximation of the original matrix.
Arguments
- x
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- by
Either a column name in
sample_info(string) or a factor/vector specifying group assignments for each sample. Used for grouping when imputing missing values.- ...
Additional arguments to pass to
pcaMethods::pca().