LoessCyc Normalization
normalize_loesscyc.RdThis function is a wrapper around limma::normalizeCyclicLoess() with
method = "pairs".
Each pair of columns is normalized mutually to each other.
See this paper for more information.
Also see limma::normalizeCyclicLoess().
Arguments
- x
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- by
Either a column name in
sample_info(string) or a factor/vector specifying group assignments for each sample. Optional. If provided, the normalization will be performed within each group.- ...
Additional arguments to pass to
limma::normalizeCyclicLoess().