normalize_median_abs.Rd
Normalize the expression matrix by dividing each column (sample) by the absolute median of that column (NA ignored), so that the absolute median of each column is 1.
normalize_median_abs(x)
A glyexp::GlycomicSE(), glyexp::GlycoproteomicSE(), or SummarizedExperiment::SummarizedExperiment() object.
glyexp::GlycomicSE()
glyexp::GlycoproteomicSE()
SummarizedExperiment::SummarizedExperiment()
A container of the same class as x, with a normalized expression matrix.
x