Robust Linear Regression with Median Adjustment Normalization
normalize_rlrma.RdThis method is based on robust linear regression with median adjustment.
First, the median of each variable's abundance across all measured samples
is subtracted from the sample's abundance values. Then, it's like the
normalize_rlr() method.
Arguments
- x
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- by
Either a column name in
sample_info(string) or a factor/vector specifying group assignments for each sample. Optional. If provided, the normalization will be performed within each group.