Plot Log-Intensity Boxplots by Sample
plot_int_boxplot.RdDraw boxplots of log2-transformed intensities for each sample. Optionally color and group samples by a metadata variable.
Arguments
- exp
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- by
Grouping variable for samples. Can be a column name in
sample_infoor a vector/factor with length equal to the number of samples. When provided, samples are grouped along the x-axis and boxplots are colored by group.
Examples
plot_int_boxplot(glyexp::real_experiment)
#> Warning: Removed 4063 rows containing non-finite outside the scale range
#> (`stat_boxplot()`).
plot_int_boxplot(glyexp::real_experiment, by = "group")
#> Warning: Removed 4063 rows containing non-finite outside the scale range
#> (`stat_boxplot()`).