Plot Missing Value Proportions by Sample or Variable
plot_missing_bar.RdDraw a bar plot of missing value proportions for each sample or variable. Items are ordered from low to high missing proportion.
Arguments
- exp
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- on
Whether to plot missingness by
"sample(s)"or"variable(s)". Defaults to"sample".
Examples
plot_missing_bar(glyexp::real_experiment)