Remove Variables with Low Coefficient of Variation
remove_low_cv.RdFilters variables whose coefficient of variation falls below a threshold. Default behavior is to remove variables with zero coefficient of variation.
Arguments
- x
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- cv_cutoff
The cutoff for coefficient of variation. Defaults to 0.
- by
A factor specifying the groupings. Defaults to NULL.
- strict
If
FALSE, remove a variable only if it passes the coefficient of variation threshold in all groups. IfTRUE, remove a variable if it passes the coefficient of variation threshold in any group.