Remove Variables with Low Expression
remove_low_expr.RdFilters variables based on median expression values. Variables with median expression values below certain percentile will be removed.
Arguments
- x
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- percentile
The percentile for median expression values. Defaults to 0.05, i.e., the 5% lowest median expression values will be removed.
- by
Either a column name in
sample_info(string) or a vector specifying group assignments for each sample.- strict
If
FALSE, remove a variable only if it passes the abundance thresholds in all groups. IfTRUE, remove a variable if it passes the abundance thresholds in any group. Defaults to FALSE.