Remove Variables with Low Variance Remove Variables with Low Variance
remove_low_var.RdFilters variables whose variance falls below a threshold. Default behavior is to remove variables with zero variance.
Arguments
- x
A
glyexp::GlycomicSE(),glyexp::GlycoproteomicSE(), orSummarizedExperiment::SummarizedExperiment()object.- var_cutoff
The cutoff for variance. Defaults to 0.
- by
A factor specifying the groupings. Defaults to NULL.
- strict
If
FALSE, remove a variable only if it passes the variance threshold in all groups. IfTRUE, remove a variable if it passes the variance threshold in any group.